# Copyright (C) 2001 by Dr. Dieter Maurer <dieter@handshake.de>
# D-66386 St. Ingbert, Eichendorffstr. 23, Germany
#
#			All Rights Reserved
#
# Permission to use, copy, modify, and distribute this software and its
# documentation for any purpose and without fee is hereby granted,
# provided that the above copyright notice and this permission
# notice appear in all copies, modified copies and in
# supporting documentation.
# 
# Dieter Maurer DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL Dieter Maurer
# BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
# DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
# PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
# TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE.
'''Utility to get help text from product source code (rather than a file).'''

from HelpSys.HelpTopic import HelpTopic
from Globals import HTML

class HelpSTXTopic_S(HelpTopic):
  '''similar to 'HelpSTXTopic' but the help text comes from a string, not from a file.'''
  def __init__(self, id, title, text, permissions=None, categories=None):
    self.id= id
    self.title= title
    self.obj= text
    if permissions is not None:
      self.permissions= permissions
    if categories is not None:
      self.categories= categories

  def index_html(self, REQUEST=None):
    '''View the STX help topic.'''
    return self.htmlfile(self,REQUEST)

  def SearchableText(self):
    "The full text of the Help Topic, for indexing purposes"
    return '%s %s' % (self.title, self.obj)

  htmlfile = HTML("""\
<dtml-var standard_html_header>
<dtml-var obj fmt="structured-text">
<dtml-var standard_html_footer>""")


def registerHelpTopic(context, id, topic):
  '''register *topic* under *id*.

  Be careful, not to do anything, if we do not need to;
  in order to avoid useless ZODB writes.'''
  help= context.getProductHelp()
  if id in help.objectIds():
    ot= getattr(help,id)
    otb= getattr(ot,'aq_base',ot)
    tb= getattr(topic,'aq_base',topic)
    if type(otb) is type(tb):
      if otb.obj == tb.obj: return
    help._delObject(id)
  context.registerHelpTopic(id,topic)
